# src package

## Subpackages

* [src.gros_client package](src.gros_client.md)
  * [Subpackages](src.gros_client.md#subpackages)
    * [src.gros_client.common package](src.gros_client.common.md)
      * [Submodules](src.gros_client.common.md#submodules)
      * [src.gros_client.common.camera module](src.gros_client.common.md#module-src.gros_client.common.camera)
      * [src.gros_client.common.system module](src.gros_client.common.md#module-src.gros_client.common.system)
      * [Module contents](src.gros_client.common.md#module-src.gros_client.common)
    * [src.gros_client.robot package](src.gros_client.robot.md)
      * [Submodules](src.gros_client.robot.md#submodules)
      * [src.gros_client.robot.car module](src.gros_client.robot.md#module-src.gros_client.robot.car)
      * [src.gros_client.robot.human module](src.gros_client.robot.md#module-src.gros_client.robot.human)
      * [src.gros_client.robot.robot_base module](src.gros_client.robot.md#module-src.gros_client.robot.robot_base)
      * [Module contents](src.gros_client.robot.md#module-src.gros_client.robot)
  * [Module contents](src.gros_client.md#module-src.gros_client)

## Module contents
